@@ -1,5 +1,5 @@
 from setuptools_scm import format_version
-from setuptools_scm.hg import archival_to_version
+from setuptools_scm.hg import archival_to_version, parse
 from setuptools_scm import integration
 
 import pytest
@@ -12,9 +12,10 @@ def wd(wd):
     wd.commit_command = 'hg commit -m test-{reason} -u test -d "0 0"'
     return wd
 
+
 archival_mapping = {
     '1.0': {'tag': '1.0'},
-    '1.1.dev3+n000000000000': {
+    '1.1.dev3+h000000000000': {
         'latesttag': '1.0',
         'latesttagdistance': '3',
         'node': '0'*20,
@@ -90,7 +91,7 @@ def test_version_from_archival(wd):
         'latesttagdistance: 3\n'
     )
 
-    assert wd.version == '0.2.dev3+n000000000000'
+    assert wd.version == '0.2.dev3+h000000000000'
 
 
 @pytest.mark.issue('#72')
@@ -101,3 +102,53 @@ def test_version_in_merge(wd):
     wd.commit_testfile()
     wd('hg merge --tool :merge')
     assert wd.version is not None
+
+
+@pytest.mark.issue(128)
+def test_parse_no_worktree(tmpdir):
+    ret = parse(str(tmpdir))
+    assert ret is None
+
+
+@pytest.fixture
+def version_1_0(wd):
+    wd('hg branch default')
+    wd.commit_testfile()
+    wd('hg tag 1.0 -u test -d "0 0"')
+    return wd
+
+
+@pytest.fixture
+def pre_merge_commit_after_tag(wd, version_1_0):
+    wd('hg branch testbranch')
+    wd.write('branchfile', 'branchtext')
+    wd(wd.add_command)
+    wd.commit()
+    wd('hg update default')
+    wd('hg merge testbranch')
+    return wd
+
+
+@pytest.mark.usefixtures("pre_merge_commit_after_tag")
+def test_version_bump_before_merge_commit(wd):
+    assert wd.version.startswith('1.1.dev1+')
+
+
+@pytest.mark.issue(219)
+@pytest.mark.usefixtures("pre_merge_commit_after_tag")
+def test_version_bump_from_merge_commit(wd):
+    wd.commit()
+    assert wd.version.startswith('1.1.dev3+')  # issue 219
+
+
+@pytest.mark.usefixtures("version_1_0")
+def test_version_bump_from_commit_including_hgtag_mods(wd):
+    """ Test the case where a commit includes changes to .hgtags and other files
+    """
+    with wd.cwd.join('.hgtags').open('a') as tagfile:
+        tagfile.write('0  0\n')
+    wd.write('branchfile', 'branchtext')
+    wd(wd.add_command)
+    assert wd.version.startswith('1.1.dev1+')  # bump from dirty version
+    wd.commit()  # commits both the testfile _and_ .hgtags
+    assert wd.version.startswith('1.1.dev2+')
